Path: csiph.com!usenet.pasdenom.info!dedibox.gegeweb.org!gegeweb.eu!nntpfeed.proxad.net!proxad.net!feeder2-2.proxad.net!newsfeed.arcor.de!newsspool1.arcor-online.net!news.arcor.de.POSTED!not-for-mail Content-Type: text/plain; charset="ISO-8859-1" Message-ID: <6163400.TXUiaJx4aB@PointedEars.de> From: Thomas 'PointedEars' Lahn Reply-To: Thomas 'PointedEars' Lahn Organization: PointedEars Software (PES) Date: Sat, 18 Aug 2012 19:54:16 +0200 User-Agent: KNode/4.4.11 Content-Transfer-Encoding: 7Bit X-Face: %i>XG-yXR'\"2P/C_aO%~;2o~?g0pPKmbOw^=NT`tprDEf++D.m7"}HW6.#=U:?2GGctkL,f89@H46O$ASoW&?s}.k+&. <$yDAFaGXyBIQFwui@invalid.uk.co.demon.merlyn.invalid> Followup-To: comp.lang.javascript MIME-Version: 1.0 Lines: 35 NNTP-Posting-Date: 18 Aug 2012 19:54:17 CEST NNTP-Posting-Host: 8c9c8561.newsspool4.arcor-online.net X-Trace: DXC=7X05Fgj[ZPFj7ehO4IUK On 08/17/2012 03:17 PM, Dr J R Stockton wrote: >> In comp.lang.javascript message , Thu, 16 >> Aug 2012 18:37:45, Norman Peelman posted: >>> MathJax appears to add a lot of code (both HTML and CSS) to the >>> document. Upon closer examination it seems to me that MathJax should >>> possibly consolidate the CSS as quite a bit is redundant. Your current >>> page alone balloons from ~109KB to ~5.3MB >> >> It was under 58kB of ASCII when it left here. That 5.3 MB must be the >> size in RAM, which hardly matters. Page authors can configure aspects >> of the loading, which might help there. > > Saving the 'generated' source (after MathJax does it's thing) results > in a 5.3MB text file. All the generated are left in even > though they aren't needed anymore That is to be expected, as the document is not expected to be saved as rendered, but as it was. Furthermore, there is no reliable method to remove all SCRIPT element nodes from a document tree once they are not needed anymore. > and many of the s created contains duplicate inline styles. That would be suboptimal, indeed. MathJax should use CSS classes, which would reduce the footprint considerably. PointedEars -- var bugRiddenCrashPronePieceOfJunk = ( navigator.userAgent.indexOf('MSIE 5') != -1 && navigator.userAgent.indexOf('Mac') != -1 ) // Plone, register_function.js:16